@@ -68,6 +68,24 @@ correct_colnames <- function(gc_peak_df,col_names) {
     return(gc_peak_df)
 }#correct_colnames
 
+delete_blank <- function(blanks, gc_peak_list_aligned, rt_col_name) {
+
+    # indices of peaks
+    delete <- sort(unique(unlist(lapply(blanks, function(fx) {
+        which(gc_peak_list_aligned[[fx]][[rt_col_name]] > 0)
+    }))))
+
+    chroma_out <- gc_peak_list_aligned
+
+    # remove blanks
+    chroma_out[blanks] <- NULL
+
+    # remove peaks from samples
+    if (length(delete) > 0) chroma_out <- lapply(chroma_out, function(x) x[-delete,])
+
+    return(chroma_out)
+}
+
 delete_empty_rows <- function(gc_peak_df, average_rts){
     gc_peak_df <- gc_peak_df[!is.na(average_rts), ]
     gc_peak_df
@@ -159,8 +177,11 @@ merge_redundant_peaks <- function(gc_peak_list,min_diff_peak2peak=0.05, rt_col_n
         while (counter != 'stop') {
             total <- ifelse(length(similar) > 0, length(similar), 1)
             # create progress bar
+
+            if (interactive()) {
             pb <- utils::txtProgressBar(min = 0, max = total, style = 3, char = "+", width = 80)
             utils::setTxtProgressBar(pb, ifelse(is.numeric(counter),counter, total))
+            }
             # stop when there are no redundancies
             if (length(similar) == 0) {
                 merging <- "stop"
@@ -182,7 +203,7 @@ merge_redundant_peaks <- function(gc_peak_list,min_diff_peak2peak=0.05, rt_col_n
             }
         }
     }
-    close(pb)
+    if (exists("pb")) close(pb)
     return(gc_peak_list)
 }#merge_redundant_peaks
 
@@ -300,7 +321,7 @@ rt_cutoff <- function(gc_peak_df, rt_col_name, low = NULL, high = NULL) {
     return(out)
 }#rt_cutoff
 
-rt_extract <- function(gc_peak_list,rt_col_name){
+rt_extract <- function(gc_peak_list, rt_col_name) {
     # blanks and del_single_sub are removed, since their removal
     # is of importance only for the last step, where it is applied
     # outside this function call
@@ -312,7 +333,7 @@ rt_extract <- function(gc_peak_list,rt_col_name){
     rt_mat2 <- rt_mat
     rt_mat2[rt_mat2 == 0] <- NA
     colnames(rt_mat) <-
-        as.character(colMeans(rt_mat2,na.rm = T)) # No rounding, are not plotted as labels anyway
+    as.character(colMeans(rt_mat2,na.rm = T)) # No rounding, are not plotted as labels anyway
     rt_mat <- cbind(id,rt_mat)
 }#rt_extract
 
